@@ -1,3 +1,7 @@
+"""
+Create curation information for example models.
+"""
+
 from fbc_curation import EXAMPLE_PATH
 from fbc_curation.fbc_files import create_fbc_files
 
@@ -14,7 +18,11 @@ def example_iJR904(results_dir):
     create_fbc_files(results_dir=results_dir, model_path=model_path)
 
 
-if __name__ == "__main__":
+def run_examples():
     results_dir = EXAMPLE_PATH / "results"
     example_ecoli_core(results_dir)
     example_iJR904(results_dir)
+
+
+if __name__ == "__main__":
+    run_examples()
